AsyncQueryMsgFns

Trait AsyncQueryMsgFns 

pub trait AsyncQueryMsgFns<Chain: AsyncWasmQuerier + ChainState, CwOrchQueryMsgType: Sync>: AsyncCwOrchQuery<Chain, QueryMsg = CwOrchQueryMsgType>
where QueryMsg: Into<CwOrchQueryMsgType>,
{ // Provided methods async fn claims_async( &self, address: impl Into<String>, ) -> Result<ClaimsResponse, CwEnvError> { ... } async fn staked_async( &self, address: impl Into<String>, ) -> Result<StakedResponse, CwEnvError> { ... } async fn admin_async(&self) -> Result<AdminResponse, CwEnvError> { ... } async fn total_weight_async( &self, ) -> Result<TotalWeightResponse, CwEnvError> { ... } async fn list_members_async( &self, limit: Option<u32>, start_after: Option<String>, ) -> Result<MemberListResponse, CwEnvError> { ... } async fn member_async( &self, addr: impl Into<String>, at_height: Option<u64>, ) -> Result<MemberResponse, CwEnvError> { ... } async fn hooks_async(&self) -> Result<HooksResponse, CwEnvError> { ... } }
Automatically derived trait that allows you to call the variants of the message directly without the need to construct the struct yourself.

Provided Methods

async fn claims_async( &self, address: impl Into<String>, ) -> Result<ClaimsResponse, CwEnvError>

Automatically generated wrapper around QueryMsg::Claims variant

async fn staked_async( &self, address: impl Into<String>, ) -> Result<StakedResponse, CwEnvError>

Automatically generated wrapper around QueryMsg::Staked variant

async fn admin_async(&self) -> Result<AdminResponse, CwEnvError>

Automatically generated wrapper around QueryMsg::Admin variant

async fn total_weight_async(&self) -> Result<TotalWeightResponse, CwEnvError>

Automatically generated wrapper around QueryMsg::TotalWeight variant

async fn list_members_async( &self, limit: Option<u32>, start_after: Option<String>, ) -> Result<MemberListResponse, CwEnvError>

Automatically generated wrapper around QueryMsg::ListMembers variant

async fn member_async( &self, addr: impl Into<String>, at_height: Option<u64>, ) -> Result<MemberResponse, CwEnvError>

Automatically generated wrapper around QueryMsg::Member variant

async fn hooks_async(&self) -> Result<HooksResponse, CwEnvError>

Automatically generated wrapper around QueryMsg::Hooks variant

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<Chain: AsyncWasmQuerier + ChainState, CwOrchQueryMsgType: Sync, SupportedContract> AsyncQueryMsgFns<Chain, CwOrchQueryMsgType> for SupportedContract
where QueryMsg: Into<CwOrchQueryMsgType>, SupportedContract: AsyncCwOrchQuery<Chain, QueryMsg = CwOrchQueryMsgType>,

Available on non-WebAssembly only.